@@ -3,9 +3,9 @@
 #' \code{xDAGpropagate} is supposed to produce a subgraph induced by the input annotation data, given a direct acyclic graph (DAG; an ontology). The input is a graph of "igraph", a list of the vertices containing annotation data, and the mode defining the paths to the root of DAG. The annotations are propagated to the ontology root (eg, retaining the minmum pvalue). The propagaged subgraph contains vertices (with annotation data) and their ancestors along with the defined paths to the root of DAG. The annotations at these vertices (including their ancestors) can also be updated according to the true-path rule: those annotated to a term should also be annotated by its all ancestor terms.
 #'
 #' @param g an object of class "igraph" to represent DAG
-#' @param annotation the vertices/nodes for which annotation data are provided. It can be a sparse Matrix of class "dgCMatrix" (with variants/genes as rows and terms as columns), or a data frame with three columns: 1st column for variants/genes, 2nd column for terms, and 3rd column for values
+#' @param annotation the vertices/nodes for which annotation data are provided. It can be a sparse Matrix of class "dgCMatrix" (with variants/genes as rows and terms as columns), or a data frame with three columns: 1st column for variants/genes, 2nd column for terms, and 3rd column for values, or a list (with the name for terms) each element storing a named vactor (that is, value for the content and variants/genes as names)
 #' @param path.mode the mode of paths induced by vertices/nodes with input annotation data. It can be "all_paths" for all possible paths to the root, "shortest_paths" for only one path to the root (for each node in query), "all_shortest_paths" for all shortest paths to the root (i.e. for each node, find all shortest paths with the equal lengths)
-#' @param propagation how to propagate the score. It can be "max" for retaining the maximum value from its children, "min" for retaining the minimum value from its children
+#' @param propagation how to propagate the score. It can be "max" for retaining the maximum value from its children, "min" for retaining the minimum value from its children, and 'all' for retaining all from its children (by default)
 #' @param verbose logical to indicate whether the messages will be displayed in the screen. By default, it sets to true for display
 #' @return 
 #' \itemize{
@@ -84,7 +84,7 @@
 #' xVisInterp(ls_xyz, nD="3D", contour=TRUE)
 #' }
 
-xDAGpropagate <- function (g, annotation, path.mode=c("all_paths","shortest_paths","all_shortest_paths"), propagation=c("min","max"), verbose=TRUE)
+xDAGpropagate <- function (g, annotation, path.mode=c("all_paths","shortest_paths","all_shortest_paths"), propagation=c("all","min","max"), verbose=TRUE)
 {
     
     path.mode <- match.arg(path.mode)
@@ -95,24 +95,27 @@ xDAGpropagate <- function (g, annotation, path.mode=c("all_paths","shortest_path
         stop("The function must apply to the 'igraph' object.\n")
     }
     
-    if(class(annotation)=="data.frame"){
-    	annotation <- xSparseMatrix(annotation, verbose=FALSE)
-    }
-    
-    if(class(annotation)=="dgCMatrix"){
-		D <- annotation
-		oAnnos <- lapply(1:ncol(D), function(j){
-			ind <- which(D[,j]!=0)
-			x <- D[ind,j]
-			names(x) <- names(ind)
-			x
-		})
-		names(oAnnos) <- colnames(annotation)
-	
+    if(class(annotation)=="list"){
+    	oAnnos <- annotation
     }else{
-    	stop("The input annotation must be either 'GS' or 'list' or 'dgCMatrix' object.\n")
-    }
-    
+		if(class(annotation)=="data.frame"){
+			annotation <- xSparseMatrix(annotation, verbose=FALSE)
+		}
+	
+		if(class(annotation)=="dgCMatrix"){
+			D <- annotation
+			oAnnos <- lapply(1:ncol(D), function(j){
+				ind <- which(D[,j]!=0)
+				x <- D[ind,j]
+				names(x) <- names(ind)
+				x
+			})
+			names(oAnnos) <- colnames(annotation)
+	
+		}else{
+			stop("The input annotation must be either 'GS' or 'list' or 'dgCMatrix' object.\n")
+		}
+	}    
     
     ## check nodes in annotation
     if (is.list(oAnnos)){
@@ -171,17 +174,32 @@ xDAGpropagate <- function (g, annotation, path.mode=c("all_paths","shortest_path
                     ### update: keep the largest score if overlap
                     all_mat <- rbind(nowDomain_mat, adjDomain_mat)
                     all_list <- base::split(x=as.numeric(all_mat[,2]), f=all_mat[,1])
-                    output_list <- lapply(all_list, function(x){
+                    output_list <- lapply(1:length(all_list), function(i){
+                    	x <- all_list[[i]]
                         if(propagation=='max'){
-                            max(x)
+                            y <- max(x)
+                            #data.frame(name=names(all_list)[i], value=y, stringsAsFactors=FALSE)
                         }else if(propagation=='min'){
-                            min(x)
+                            y <- min(x)
+                            #data.frame(name=names(all_list)[i], value=y, stringsAsFactors=FALSE)
+                        }else{
+                        	y <- unique(x)
                         }
+                        data.frame(name=rep(names(all_list)[i],length(y)), value=y, stringsAsFactors=FALSE)
                     })
-                    x_mat <- base::do.call(base::rbind, output_list)
-                    output <- as.vector(x_mat)
-                    names(output) <- rownames(x_mat)
+                    
+                    if(0){
+						x_mat <- base::do.call(base::rbind, output_list)
+						output <- as.vector(x_mat)
+						names(output) <- rownames(x_mat)
+                	}else{
+						x_mat <- base::do.call(base::rbind, output_list)
+						output <- x_mat$value
+						names(output) <- x_mat$name
+                	}
+                	
                     return(output)
+                    
                 })
                 pAnnos[adjNodes] <- res
             }
