@@ -4,7 +4,7 @@
 #'
 #' @param eTerm an object of class "eTerm"
 #' @param top_num the number of the top terms (sorted according to 'sortBy' below) will be viewed
-#' @param sortBy which statistics will be used for sorting and viewing gene sets (terms). It can be "adjp" or "fdr" for adjusted p value (FDR), "pvalue" for p value, "zscore" for enrichment z-score, "fc" for enrichment fold change, "nAnno" for the number of sets (terms), "nOverlap" for the number in overlaps, and "none" for ordering according to ID of terms
+#' @param sortBy which statistics will be used for sorting and viewing gene sets (terms). It can be "adjp" or "fdr" for adjusted p value (FDR), "pvalue" for p value, "zscore" for enrichment z-score, "fc" for enrichment fold change, "nAnno" for the number of sets (terms), "nOverlap" for the number in overlaps, "or" for the odds ratio, and "none" for ordering according to ID of terms
 #' @param decreasing logical to indicate whether to sort in a decreasing order. If it is null, it would be true for "zscore", "nAnno" or "nOverlap"; otherwise it would be false
 #' @param details logical to indicate whether the detailed information of gene sets (terms) is also viewed. By default, it sets to false for no inclusion
 #' @return
@@ -18,7 +18,10 @@
 #'  \item{\code{zscore}: enrichment z-score}
 #'  \item{\code{pvalue}: nominal p value}
 #'  \item{\code{adjp}: adjusted p value (FDR)}
-#'  \item{\code{distance}: term distance; optional, it is only appended when "details" is true}
+#'  \item{\code{or}: a vector containing odds ratio}
+#'  \item{\code{CIl}: a vector containing lower bound confidence interval for the odds ratio}
+#'  \item{\code{CIu}: a vector containing upper bound confidence interval for the odds ratio}
+#'  \item{\code{distance}: term distance or other information; optional, it is only appended when "details" is true}
 #'  \item{\code{members}: members (represented as Gene Symbols) in overlaps; optional, it is only appended when "details" is true}
 #' }
 #' @note none
@@ -30,7 +33,7 @@
 #' xEnrichViewer(eTerm)
 #' }
 
-xEnrichViewer <- function(eTerm, top_num=10, sortBy=c("adjp","fdr","pvalue","zscore","fc","nAnno","nOverlap","none"), decreasing=NULL, details=F) 
+xEnrichViewer <- function(eTerm, top_num=10, sortBy=c("adjp","fdr","pvalue","zscore","fc","nAnno","nOverlap","or","none"), decreasing=NULL, details=F) 
 {
     
     sortBy <- match.arg(sortBy)
@@ -39,8 +42,9 @@ xEnrichViewer <- function(eTerm, top_num=10, sortBy=c("adjp","fdr","pvalue","zsc
     	sortBy <- 'adjp'
     }
     
-    if(is.logical(eTerm)){
-        stop("There is no enrichment in the 'eTerm' object.\n")
+    if(is.null(eTerm)){
+        warnings("There is no enrichment in the 'eTerm' object.\n")
+        return(NULL)
     }
     
     if(class(eTerm) == "data.frame" ){
@@ -74,8 +78,12 @@ xEnrichViewer <- function(eTerm, top_num=10, sortBy=c("adjp","fdr","pvalue","zsc
 							   zscore       = as.numeric(eTerm$zscore),
 							   pvalue       = as.numeric(eTerm$pvalue),
 							   adjp         = as.numeric(eTerm$adjp),
+							   or         	= as.numeric(eTerm$or),
+							   CIl         	= as.numeric(eTerm$CIl),
+							   CIu         	= as.numeric(eTerm$CIu),
 							   distance     = eTerm$term_info$distance,
-							   members      = sapply(eTerm$overlap, function(x) paste(x,collapse=', ')),
+							   namespace    = eTerm$term_info$namespace,
+							   members      = sapply(eTerm$overlap, function(x) paste(sort(x),collapse=', ')),
 							   stringsAsFactors=F
 							  )
 		}else{
@@ -86,8 +94,12 @@ xEnrichViewer <- function(eTerm, top_num=10, sortBy=c("adjp","fdr","pvalue","zsc
 							   zscore       = as.numeric(eTerm$zscore),
 							   pvalue       = as.numeric(eTerm$pvalue),
 							   adjp         = as.numeric(eTerm$adjp),
+							   or         	= as.numeric(eTerm$or),
+							   CIl         	= as.numeric(eTerm$CIl),
+							   CIu         	= as.numeric(eTerm$CIu),
 							   distance     = eTerm$term_info$distance,
-							   members      = sapply(eTerm$overlap, function(x) paste(x,collapse=', ')),
+							   namespace    = eTerm$term_info$namespace,
+							   members      = sapply(eTerm$overlap, function(x) paste(sort(x),collapse=', ')),
 							   stringsAsFactors=F
 							  )
 		}
@@ -96,13 +108,13 @@ xEnrichViewer <- function(eTerm, top_num=10, sortBy=c("adjp","fdr","pvalue","zsc
 	}
 	    
     if(details == T){
-        res <- tab[,c(1:9)]
+        res <- tab[,c(1:13)]
     }else{
-        res <- tab[,c(1:7)]
+        res <- tab[,c(1:10)]
     }
     
     if(is.null(decreasing)){
-        if(sortBy=="zscore" | sortBy=="nAnno" | sortBy=="nOverlap"){
+        if(sortBy=="zscore" | sortBy=="nAnno" | sortBy=="nOverlap" | sortBy=="or"){
             decreasing <- T
         }else{
             decreasing <- F
@@ -114,6 +126,7 @@ xEnrichViewer <- function(eTerm, top_num=10, sortBy=c("adjp","fdr","pvalue","zsc
     	pvalue={res <- res[with(res,order(pvalue,-zscore))[1:top_num],]},
     	zscore={res <- res[with(res,order(-zscore,adjp))[1:top_num],]},
     	fc={res <- res[with(res,order(-fc,adjp))[1:top_num],]},
+    	or={res <- res[with(res,order(-or,adjp))[1:top_num],]},
     	nAnno={res <- res[with(res,order(-nAnno,adjp,-zscore))[1:top_num],]},
     	nOverlap={res <- res[with(res,order(-nOverlap,adjp,-zscore))[1:top_num],]},
         none={res <- res[order(rownames(res), decreasing=decreasing)[1:top_num],]}
